@@ -4,7 +4,7 @@ import os
 
 class BotShynaTelegram:
     token = os.environ.get('bot_token')
-    bot = telegram.Bot(token=token)
+    bot = telegram.Bot(token=os.environ.get('bot_token'))
     news_bot = telegram.Bot(token=os.environ.get('news_bot_token'))
     broadcast_bot = telegram.Bot(token=os.environ.get('broadcast_bot_token'))
     status = False
